==> kdevplatform-0.9.96.tar.bz2: kdevplatform-0.9.96/plugins/projectmanagerview/builditembuilderjob.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef BUILDITEM_BUILDERJOB_H
#define BUILDITEM_BUILDERJOB_H

#include <QtCore/QList>

#include <project/builderjob.h>

namespace KDevelop
{
class ProjectBaseItem;
class IProject;
}

class BuildItem;

class BuildItemBuilderJob : public KDevelop::BuilderJob
{
    Q_OBJECT
public:
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<BuildItem>& );
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<KDevelop::ProjectBaseItem*>& items );
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<KDevelop::IProject*>& items );
};

#endif

//kate: space-indent on; indent-width 4; replace-tabs on; auto-insert-doxygen on; indent-mode cstyle;

==> kdevplatform-1.2.81.tar.bz2: kdevplatform-1.2.81/plugins/projectmanagerview/builditembuilderjob.h <==
/***************************************************************************
 *   This file is part of KDevelop                                         *
 *   Copyright 2007 Andreas Pakulat <apaku@gmx.de>                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef BUILDITEM_BUILDERJOB_H
#define BUILDITEM_BUILDERJOB_H

#include <QtCore/QList>

#include <project/builderjob.h>

namespace KDevelop
{
class ProjectBaseItem;
class IProject;
class BuildItem;
}

class BuildItemBuilderJob : public KDevelop::BuilderJob
{
    Q_OBJECT
public:
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<KDevelop::BuildItem>& );
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<KDevelop::ProjectBaseItem*>& items );
    BuildItemBuilderJob( KDevelop::BuilderJob::BuildType, const QList<KDevelop::IProject*>& items );
};

#endif

//kate: space-indent on; indent-width 4; replace-tabs on; auto-insert-doxygen on; indent-mode cstyle;
